#
# spec file for package python-convertdate
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-convertdate
Version:        2.4.0
Release:        1.7
Summary:        Module for date conversions from and to Gregorian calendar
License:        MIT
URL:            https://github.com/fitnr/convertdate
Source:         https://github.com/fitnr/convertdate/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyMeeus >= 0.3.6
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyMeeus >= 0.3.6}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
# /SECTION
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
A Python module for converting between Gregorian dates and other
calendar systems. Calendars included: Baha'i, French Republican,
Hebrew, Indian Civil, Islamic, ISO, Julian, Mayan and Persian.

%prep
%setup -q -n convertdate-%{version}
sed -i -e 's:, < 2020::g' setup.py

%build
export LC_ALL="en_US.UTF8"
%pyproject_wheel

%install
export LC_ALL="en_US.UTF8"
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/censusgeocode

%check
export LC_ALL="en_US.UTF8"
%pytest %{?jobs:-n %jobs}

%post
%python_install_alternative censusgeocode

%postun
%python_uninstall_alternative censusgeocode

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/censusgeocode
%{python_sitelib}/convertdate
%{python_sitelib}/convertdate-%{version}.dist-info

%changelog
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.4.0:
  * Drop official support for Python version 3.5 and 3.6, which
    have reached end-of-life.
  * Remove pytz dependency (#49)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Wed Mar 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.2:
  * Switch Persian calendar to astronomical computation (was non-canonical algorithmic method)
  * Fix inappropriate uses of trunc, which caused several errors before the Julian Day epoch (#39, #40, #42)
  * Fix bug in julian.leap (#43)
  * Add official suppport and tests for Python 3.9
  * Raise ValueError for attempted conversion of dates before the Mayan epoch
  * Fix bug in Bahai calculations during Ayyám-i-Há (#32). Thanks @chiuczek
  * Regularize variable names:
  * coptic: rename MONTH_NAMES to MONTHS, rename DAY_NAMES to WEEKDAYS
  * french_republican: add MONTHS
  * mayan: rename HAAB_MONTHS to HAAB, rename TZOLKIN_NAMES to TZOLKIN
  * Add some Jewish and Islamic holidays to holidays: shemini_azeret, lag_baomer, tu_beshvat, tisha_bav, ramadan, ashura, eid_alfitr, eid_aladha
  * Add docs. See https://convertdate.readthedocs.io/
  * Fix December 31st bug in ordinal (#34)
  * Add Indigenous Peoples' Day and Juneteenth to holidays, deprecate Columbus day
- Switch to using pytest
* Mon May  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not restrict upper version on pytz for no reason.
* Wed Apr  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.2.0
  * Repair Bahai intercalary days bug (#13, thanks @bchurchill)
  * Replace pyephem, which is now in maintenance mode, with pymeeus.
  * Remove shebangs and regularize licenses (thanks @fabaff)
  * Convert readme to ascii (#16)
* Fri Oct 18 2019 Dirk Mueller <dmueller@suse.com>
- fix execution of tests on anything older than Tumbleweed
* Fri Sep 13 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase.
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable tests
- Format with spec-cleaner
* Wed Apr  3 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.1.3
